==> yui_editor-6.x-1.2-8.tar.gz: yui_editor/yui_editor.js <==
function render_editor(id, config) {
  if ($("#"+id).val() != null) {

    var myConfig = {
      height: config.height,
      width: config.width,
      dompath: config.dom,
      animate: true,
      handleSubmit: true,
      markup: config.markup,
      toolbar: yui_editor_toolbar.toolbar
    };
    myConfig.toolbar.titlebar = config.title;
    myConfig.toolbar.collapse = config.collapse;
    myConfig.toolbar.draggable = config.draggable;
    myConfig.toolbar.buttonType = config.buttonType;

    $(document).ready(function() {
      $(".grippie").hide();
      $(".teaser-checkbox").hide();
      YAHOO.util.Dom.setStyle('toggleEditor-'+id, 'margin-top', '1.7em');
    });

    var myEditor = new YAHOO.widget.Editor(id, myConfig);
    if (! config.titlebar) {
      myEditor._defaultToolbar.titlebar = config.titlebar;
    }
    myEditor.render();

    if (config.resize == 1) {
      myEditor.on('editorContentLoaded', function() {
        resize = new YAHOO.util.Resize(myEditor.get('element_cont').get('element'), {
          handles: ['br'],
          autoRatio: true,
          status: true,
          proxy: true
        });
        resize.on('startResize', function() {
          this.hide();
          this.set('disabled', true);
        }, myEditor, true);
        resize.on('resize', function(args) {
          var h = args.height;
          var th = (this.toolbar.get('element').clientHeight + 2); //It has a 1px border..
          var dh = (this.dompath.clientHeight + 1); //It has a 1px top border..
          var newH = (h - th - dh);
          this.set('width', args.width + 'px');
          this.set('height', newH + 'px');
          this.set('disabled', false);
          this.show();
        }, myEditor, true);
      });
    }

    if (config.plaintext == 1) {
      var state = 'on';

      var Dom = YAHOO.util.Dom,
      Event = YAHOO.util.Event;

      $("#"+id).after("<button id=\"toggleEditor-"+id+"\">"+ Drupal.t('Switch to Plain Editor') +"</button>");
      var _button = new YAHOO.widget.Button('toggleEditor-'+id);
      _button.addClass('toggleEditor');

      _button.on('click', function(ev) {
        Event.stopEvent(ev);
        if (state == 'on') {
          state = 'off';
          myEditor.saveHTML();
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'position', 'absolute');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'top', '-9999px');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'left', '-9999px');
          myEditor.get('element_cont').removeClass('yui-editor-container');
          Dom.setStyle(myEditor.get('element'), 'visibility', 'visible');
          Dom.setStyle(myEditor.get('element'), 'top', '');
          Dom.setStyle(myEditor.get('element'), 'left', '');
          Dom.setStyle(myEditor.get('element'), 'position', 'static');
          _button.set("label", Drupal.t('Switch to Rich Text Editor'));

          $(".grippie").show();
          $(".teaser-checkbox").show();
        }
        else {
          state = 'on';
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'position', 'static');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'top', '0');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'left', '0');
          Dom.setStyle(myEditor.get('element'), 'visibility', 'hidden');
          Dom.setStyle(myEditor.get('element'), 'top', '-9999px');
          Dom.setStyle(myEditor.get('element'), 'left', '-9999px');
          Dom.setStyle(myEditor.get('element'), 'position', 'absolute');
          myEditor.get('element_cont').addClass('yui-editor-container');
          myEditor._setDesignMode('on');
          myEditor.setEditorHTML(myEditor.get('textarea').value);
          _button.set("label", Drupal.t('Switch to Plain Editor'));
          $(".grippie").hide();
          $(".teaser-checkbox").hide();
        }
      });
    }




/*
    var Dom = YAHOO.util.Dom,
        Event = YAHOO.util.Event;
    

    var state = 'off';
    myEditor.on('toolbarLoaded', function() {
        var codeConfig = {
            type: 'push', label: 'Edit HTML Code', value: 'editcode'
        };
        YAHOO.log('Create the (editcode) Button', 'info', 'example');
        this.toolbar.addButtonToGroup(codeConfig, 'insertitem');
        
        this.toolbar.on('editcodeClick', function() {
            var ta = this.get('element'),
                iframe = this.get('iframe').get('element');

            if (state == 'on') {
                state = 'off';
                this.toolbar.set('disabled', false);
                YAHOO.log('Show the Editor', 'info', 'example');
                YAHOO.log('Inject the HTML from the textarea into the editor', 'info', 'example');
                this.setEditorHTML(ta.value);
                if (!this.browser.ie) {
                    this._setDesignMode('on');
                }

                Dom.removeClass(iframe, 'editor-hidden');
                Dom.addClass(ta, 'editor-hidden');
                this.show();
                this._focusWindow();
            } else {
                state = 'on';
                YAHOO.log('Show the Code Editor', 'info', 'example');
                this.cleanHTML();
                YAHOO.log('Save the Editors HTML', 'info', 'example');
                Dom.addClass(iframe, 'editor-hidden');
                Dom.removeClass(ta, 'editor-hidden');
                this.toolbar.set('disabled', true);
                this.toolbar.getButtonByValue('editcode').set('disabled', false);
                this.toolbar.selectButton('editcode');
                this.dompath.innerHTML = 'Editing HTML Code';
                this.hide();
            }
            return false;
        }, this, true);

        this.on('cleanHTML', function(ev) {
            YAHOO.log('cleanHTML callback fired..', 'info', 'example');
            this.get('element').value = ev.html;
        }, this, true);
        
        this.on('afterRender', function() {
            var wrapper = this.get('editor_wrapper');
            wrapper.appendChild(this.get('element'));
            this.setStyle('width', '100%');
            this.setStyle('height', '100%');
            this.setStyle('visibility', '');
            this.setStyle('top', '');
            this.setStyle('left', '');
            this.setStyle('position', '');

            this.addClass('editor-hidden');
        }, this, true);
    }, myEditor, true);
*/


  }
};

==> yui_editor-6.x-1.2-9.tar.gz: yui_editor/yui_editor.js <==
function render_editor(id, config) {
  if ($("#"+id).val() != null) {

    var Dom = YAHOO.util.Dom,
    Event = YAHOO.util.Event;

    var newToolbar = new yui_editor_toolbar;
    var myConfig = {
      height: config.height,
      width: config.width,
      dompath: config.dom,
      animate: true,
      //handleSubmit: true,
      markup: config.markup,
      toolbar: newToolbar.toolbar
    };
    myConfig.toolbar.titlebar = config.title;
    myConfig.toolbar.collapse = config.collapse;
    myConfig.toolbar.draggable = config.draggable;
    myConfig.toolbar.buttonType = config.buttonType;

    $(document).ready(function() {
      $(".grippie").hide();
      $(".teaser-checkbox").hide();
      YAHOO.util.Dom.setStyle('toggleEditor-'+id, 'margin-top', '1.7em');
    });

    var myEditor = new YAHOO.widget.Editor(id, myConfig);
    if (! config.titlebar) {
      myEditor._defaultToolbar.titlebar = config.titlebar;
    }

    myEditor.render();

    if (config.resize == 1) {
      myEditor.on('editorContentLoaded', function() {
        resize = new YAHOO.util.Resize(myEditor.get('element_cont').get('element'), {
          handles: ['br'],
          autoRatio: true,
          status: true,
          proxy: true
        });
        resize.on('startResize', function() {
          this.hide();
          this.set('disabled', true);
        }, myEditor, true);
        resize.on('resize', function(args) {
          var h = args.height;
          var th = (this.toolbar.get('element').clientHeight + 2); //It has a 1px border..
          var dh = (this.dompath.clientHeight + 1); //It has a 1px top border..
          var newH = (h - th - dh);
          this.set('width', args.width + 'px');
          this.set('height', newH + 'px');
          this.set('disabled', false);
          this.show();
        }, myEditor, true);
      });
    }

    if (config.plaintext == 1) {
      var plaintextState = 'on';

      $("#"+id).after("<button id=\"toggleEditor-"+id+"\">"+ Drupal.t('Switch to Plain Editor') +"</button>");
      var _button = new YAHOO.widget.Button('toggleEditor-'+id);
      _button.addClass('toggleEditor');

      _button.on('click', function(ev) {
        Event.stopEvent(ev);
        if (plaintextState == 'on') {
          plaintextState = 'off';
          myEditor.saveHTML();
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'position', 'absolute');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'top', '-9999px');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'left', '-9999px');
          myEditor.get('element_cont').removeClass('yui-editor-container');
          Dom.setStyle(myEditor.get('element'), 'visibility', 'visible');
          Dom.setStyle(myEditor.get('element'), 'top', '');
          Dom.setStyle(myEditor.get('element'), 'left', '');
          Dom.setStyle(myEditor.get('element'), 'position', 'static');
          _button.set("label", Drupal.t('Switch to Rich Text Editor'));

          $(".grippie").show();
          $(".teaser-checkbox").show();
        }
        else {
          plaintextState = 'on';
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'position', 'static');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'top', '0');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'left', '0');
          Dom.setStyle(myEditor.get('element'), 'visibility', 'hidden');
          Dom.setStyle(myEditor.get('element'), 'top', '-9999px');
          Dom.setStyle(myEditor.get('element'), 'left', '-9999px');
          Dom.setStyle(myEditor.get('element'), 'position', 'absolute');
          myEditor.get('element_cont').addClass('yui-editor-container');
          myEditor._setDesignMode('on');
          myEditor.setEditorHTML(myEditor.get('textarea').value);
          _button.set("label", Drupal.t('Switch to Plain Editor'));
          $(".grippie").hide();
          $(".teaser-checkbox").hide();
        }
      });
    }

    if (config.coder == 1) {
      var coderState = 'off';

      myEditor.on('toolbarLoaded', function() {
        var codeConfig = {
          type: 'push', label: 'Edit HTML Code', value: 'editcode'
        };
        this.toolbar.addButtonToGroup(codeConfig, 'insertitem');

        this.toolbar.on('editcodeClick', function() {
          var ta = this.get('element'),
            iframe = this.get('iframe').get('element');

          if (coderState == 'on') {
            coderState = 'off';
            this.toolbar.set('disabled', false);
            this.setEditorHTML(ta.value);
            if (!this.browser.ie) {
              this._setDesignMode('on');
            }

            Dom.removeClass(iframe, 'editor-hidden');
            Dom.addClass(ta, 'editor-hidden');
            this.show();
            this._focusWindow();
          }
          else {
            coderState = 'on';
            this.cleanHTML();
            Dom.addClass(iframe, 'editor-hidden');
            Dom.removeClass(ta, 'editor-hidden');
            this.toolbar.set('disabled', true);
            this.toolbar.getButtonByValue('editcode').set('disabled', false);
            this.toolbar.selectButton('editcode');
            this.dompath.innerHTML = 'Editing HTML Code';
            this.hide();
          }

          return false;
        }, this, true);

        this.on('cleanHTML', function(ev) {
          this.get('element').value = ev.html;
        }, this, true);
        
        this.on('afterRender', function() {
          var wrapper = this.get('editor_wrapper');
          wrapper.appendChild(this.get('element'));
          this.setStyle('width', '100%');
          this.setStyle('height', '100%');
          this.setStyle('visibility', '');
          this.setStyle('top', '');
          this.setStyle('left', '');
          this.setStyle('position', '');

          this.addClass('editor-hidden');
        }, this, true);
      }, myEditor, true);
    }
  }
};
